Outputs a `summary.qbld' class object, and prints as described.
# S3 method for qbld
summary(object,quantiles = c(0.025, 0.25, 0.5, 0.75, 0.975),epsilon = 0.05,...)# S3 method for summary.qbld
print(x, ...)
: `qbld' class object
: Vector of quantiles for summary of the covariates,
defaulted to c(0.025, 0.25, 0.5, 0.75, 0.975)
: epsilon value for calculating significance stars (see details), 0.05 by default.
: Other summary arguments
: (for print.summary.qbld) `qbld.summary' class object
summary.qbld produces following sets of summary statistics for each variable:
statistics: Contains the mean, sd, markov std error, ess and Gelman-Rubin diagnostic
quantiles: Contains quantile estimates for each variable
nsim: No. of simulations run
burn: Burn-in used or not
which: Block, or Unblock version of sampler
p: quantile for the AL distribution on the error term
multiess: multiess value for the sample
multigelman: multivariate version of Gelman-Rubin
`qbld.summary' class summarizes the outputs of the model.qbld function. Markov Std Error (MCSE), Effective sample size (ESS) are calculated using mcmcse package. Gelman-Rubin diagnostic (R hat), and significance stars are indicated using Vats and Knudson et. al.
Vats, Dootika and Christina Knudson. <U+201C>Revisiting the Gelman-Rubin Diagnostic.<U+201D> arXiv
James M. Flegal, John Hughes, Dootika Vats, and Ning Dai. (2020). mcmcse: Monte Carlo Standard Errors for MCMC. R package version 1.4-1. Riverside, CA, Denver, CO, Coventry, UK, and Minneapolis, MN.
Christina Knudson and Dootika Vats (2020). stableGR: A Stable Gelman-Rubin Diagnostic for Markov Chain Monte Carlo. R package version 1.0.
Additional functions : mcse.mat, ess, multiESS,
stable.GR, target.psrf